@@ -21,10 +21,8 @@ import argparse
 import logging
 import os
 
-from oslo_log import versionutils
 from oslo_utils import encodeutils
 from oslo_utils import importutils
-import six
 
 from tackerclient.common import exceptions
 from tackerclient.i18n import _
@@ -141,7 +139,7 @@ def http_log_resp(_logger, resp, body):
 
 
 def _safe_encode_without_obj(data):
-    if isinstance(data, six.string_types):
+    if isinstance(data, str):
         return encodeutils.safe_encode(data)
     return data
 
@@ -178,9 +176,3 @@ def get_file_path(filename):
     file_path = os.path.abspath(os.path.join(os.path.dirname(__file__),
                                              '../%s' % filename))
     return file_path
-
-
-def deprecate_warning(what, as_of, in_favor_of=None, remove_in=1):
-    versionutils.deprecation_warning(as_of=as_of, what=what,
-                                     in_favor_of=in_favor_of,
-                                     remove_in=remove_in)
