@@ -43,16 +43,7 @@ from tackerclient.common import exceptions as exc
 from tackerclient.common import extension as client_extension
 from tackerclient.common import utils
 from tackerclient.i18n import _
-from tackerclient.tacker.v1_0.events import events
-from tackerclient.tacker.v1_0 import extension
-from tackerclient.tacker.v1_0.nfvo import ns
-from tackerclient.tacker.v1_0.nfvo import nsd
 from tackerclient.tacker.v1_0.nfvo import vim
-from tackerclient.tacker.v1_0.nfvo import vnfcluster
-from tackerclient.tacker.v1_0.nfvo import vnffg
-from tackerclient.tacker.v1_0.nfvo import vnffgd
-from tackerclient.tacker.v1_0.vnfm import vnf
-from tackerclient.tacker.v1_0.vnfm import vnfd
 from tackerclient.version import __version__
 
 
@@ -105,79 +96,13 @@ class BashCompletionCommand(openstack_command.OpenStackCommand):
 
 COMMAND_V1 = {
     'bash-completion': BashCompletionCommand,
-    'ext-list': extension.ListExt,
-    'ext-show': extension.ShowExt,
 
     # MANO lingo
-    'vnfd-create': vnfd.CreateVNFD,
-    'vnfd-delete': vnfd.DeleteVNFD,
-    'vnfd-list': vnfd.ListVNFD,
-    'vnfd-show': vnfd.ShowVNFD,
-    'vnfd-template-show': vnfd.ShowTemplateVNFD,
-
-    'vnf-create': vnf.CreateVNF,
-    'vnf-update': vnf.UpdateVNF,
-    'vnf-delete': vnf.DeleteVNF,
-    'vnf-list': vnf.ListVNF,
-    'vnf-show': vnf.ShowVNF,
-    'vnf-scale': vnf.ScaleVNF,
-    'vnf-resource-list': vnf.ListVNFResources,
-    # 'vnf-config-create'
-    # 'vnf-config-push'
-
     'vim-register': vim.CreateVIM,
     'vim-update': vim.UpdateVIM,
     'vim-delete': vim.DeleteVIM,
     'vim-list': vim.ListVIM,
-    'vim-show': vim.ShowVIM,
-
-    'events-list': events.ListResourceEvents,
-    'event-show': events.ShowEvent,
-    'vnf-events-list': events.ListVNFEvents,
-    'vim-events-list': events.ListVIMEvents,
-    'vnfd-events-list': events.ListVNFDEvents,
-
-    'vnffgd-create': vnffgd.CreateVNFFGD,
-    'vnffgd-delete': vnffgd.DeleteVNFFGD,
-    'vnffgd-list': vnffgd.ListVNFFGD,
-    'vnffgd-show': vnffgd.ShowVNFFGD,
-    'vnffgd-template-show': vnffgd.ShowTemplateVNFFGD,
-
-    'vnffg-create': vnffg.CreateVNFFG,
-    'vnffg-delete': vnffg.DeleteVNFFG,
-    'vnffg-list': vnffg.ListVNFFG,
-    'vnffg-show': vnffg.ShowVNFFG,
-    'vnffg-update': vnffg.UpdateVNFFG,
-
-    'nfp-list': vnffg.ListNFP,
-    'nfp-show': vnffg.ShowNFP,
-
-    'chain-list': vnffg.ListSFC,
-    'chain-show': vnffg.ShowSFC,
-
-    'classifier-list': vnffg.ListFC,
-    'classifier-show': vnffg.ShowFC,
-
-    'nsd-create': nsd.CreateNSD,
-    'nsd-list': nsd.ListNSD,
-    'nsd-delete': nsd.DeleteNSD,
-    'nsd-show': nsd.ShowNSD,
-    'nsd-template-show': nsd.ShowTemplateNSD,
-
-    'ns-create': ns.CreateNS,
-    'ns-list': ns.ListNS,
-    'ns-delete': ns.DeleteNS,
-    'ns-show': ns.ShowNS,
-
-    'cluster-create': vnfcluster.CreateCluster,
-    'cluster-delete': vnfcluster.DeleteCluster,
-    'cluster-list': vnfcluster.ListCluster,
-    'cluster-show': vnfcluster.ShowCluster,
-
-    'cluster-member-add': vnfcluster.AddClusterMember,
-    'cluster-member-show': vnfcluster.ShowClusterMember,
-    'cluster-member-list': vnfcluster.ListClusterMember,
-    'cluster-member-delete': vnfcluster.DeleteClusterMember,
+    'vim-show': vim.ShowVIM
 }
 
 COMMANDS = {'1.0': COMMAND_V1}
